@@ -2,21 +2,7 @@
  *
  * Copyright (C) 2014 Richard Hughes <richard@hughsie.com>
  *
- * Licensed under the GNU Lesser General Public License Version 2.1
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * SPDX-License-Identifier: LGPL-2.1+
  */
 
 /**
@@ -501,7 +487,7 @@ asb_package_get_filelist (AsbPackage *pkg)
  * asb_package_get_deps:
  * @pkg: A #AsbPackage
  *
- * Get the package dependancy list.
+ * Get the package dependency list.
  *
  * Returns: (transfer none) (element-type utf8): deplist
  *
@@ -706,7 +692,7 @@ asb_package_set_source_pkgname (AsbPackage *pkg, const gchar *source_pkgname)
  * @pkg: A #AsbPackage
  * @dep: package dep
  *
- * Add a package dependancy.
+ * Add a package dependency.
  *
  * Since: 0.3.5
  **/
@@ -1158,12 +1144,12 @@ asb_package_compare (AsbPackage *pkg1, AsbPackage *pkg2)
 		return 1;
 
 	/* check version */
-	rc = as_utils_vercmp (priv1->version, priv2->version);
+	rc = as_utils_vercmp_full (priv1->version, priv2->version, AS_VERSION_COMPARE_FLAG_NONE);
 	if (rc != 0)
 		return rc;
 
 	/* check release */
-	rc = as_utils_vercmp (priv1->release, priv2->release);
+	rc = as_utils_vercmp_full (priv1->release, priv2->release, AS_VERSION_COMPARE_FLAG_NONE);
 	if (rc != 0)
 		return rc;
 
