@@ -28,8 +28,7 @@ asb_plugin_add_globs (AsbPlugin *plugin, GPtrArray *globs)
 static gboolean
 _asb_plugin_check_filename (const gchar *filename)
 {
-	if (asb_plugin_match_glob ("*.metainfo.xml", filename) ||
-	    asb_plugin_match_glob ("/usr/share/appdata/*.metainfo.xml", filename) ||
+	if (asb_plugin_match_glob ("/usr/share/appdata/*.metainfo.xml", filename) ||
 	    asb_plugin_match_glob ("/usr/share/appdata/*.appdata.xml", filename) ||
 	    asb_plugin_match_glob ("/usr/share/metainfo/*.metainfo.xml", filename) ||
 	    asb_plugin_match_glob ("/usr/share/metainfo/*.appdata.xml", filename))
@@ -89,25 +88,6 @@ asb_plugin_process_filename (AsbPlugin *plugin,
 				 as_problem_get_message (problem));
 	}
 
-	/* fix up the project license */
-	tmp = as_app_get_project_license (AS_APP (app));
-	if (tmp != NULL && !as_utils_is_spdx_license (tmp)) {
-		g_autofree gchar *license_spdx = NULL;
-		license_spdx = as_utils_license_to_spdx (tmp);
-		if (as_utils_is_spdx_license (license_spdx)) {
-			asb_package_log (asb_app_get_package (app),
-					 ASB_PACKAGE_LOG_LEVEL_WARNING,
-					 "project license fixup: %s -> %s",
-					 tmp, license_spdx);
-			as_app_set_project_license (AS_APP (app), license_spdx);
-		} else {
-			asb_package_log (asb_app_get_package (app),
-					 ASB_PACKAGE_LOG_LEVEL_WARNING,
-					 "project license is invalid: %s", tmp);
-			as_app_set_project_license (AS_APP (app), NULL);
-		}
-	}
-
 	/* check license */
 	tmp = as_app_get_metadata_license (AS_APP (app));
 	if (tmp == NULL) {
@@ -118,14 +98,6 @@ asb_plugin_process_filename (AsbPlugin *plugin,
 			     filename);
 		return FALSE;
 	}
-	if (!as_utils_is_spdx_license (tmp)) {
-		g_set_error (error,
-			     ASB_PLUGIN_ERROR,
-			     ASB_PLUGIN_ERROR_FAILED,
-			     "AppData %s license '%s' invalid",
-			     filename, tmp);
-		return FALSE;
-	}
 
 	/* log updateinfo */
 	tmp = as_app_get_update_contact (AS_APP (app));
