@@ -8,8 +8,7 @@
 #include "config.h"
 
 #include <gdk-pixbuf/gdk-pixbuf.h>
-#include <libsoup/soup.h>
-#include <libsoup/soup-status.h>
+#include <curl/curl.h>
 #include <string.h>
 
 #include "as-app-private.h"
@@ -22,7 +21,8 @@ typedef struct {
 	AsAppValidateFlags	 flags;
 	GPtrArray		*screenshot_urls;
 	GPtrArray		*probs;
-	SoupSession		*session;
+	CURL			*curl;
+	GProxyResolver		*proxy_resolver;
 	gboolean		 previous_para_was_short;
 	gchar			*previous_para_was_short_str;
 	guint			 para_chars_before_list;
@@ -137,7 +137,7 @@ as_app_validate_has_first_word_capital (AsAppValidateHelper *helper, const gchar
 	}
 
 	/* is the first word the project name */
-	if (g_strcmp0 (first_word, as_app_get_name (helper->app, NULL)) == 0)
+	if (g_strcmp0 (first_word, as_app_get_name (helper->app, "C")) == 0)
 		return TRUE;
 
 	return FALSE;
@@ -413,25 +413,36 @@ as_app_validate_image_url_already_exists (AsAppValidateHelper *helper,
 	return FALSE;
 }
 
+static size_t
+as_app_validate_download_write_callback_cb(char *ptr, size_t size, size_t nmemb, void *userdata)
+{
+	GByteArray *buf = (GByteArray *)userdata;
+	gsize realsize = size * nmemb;
+	g_byte_array_append(buf, (const guint8 *)ptr, realsize);
+	return realsize;
+}
+
 static gboolean
 ai_app_validate_image_check (AsImage *im, AsAppValidateHelper *helper)
 {
 	AsImageAlphaFlags alpha_flags;
+	CURLcode res;
 	const gchar *url;
 	gboolean require_correct_aspect_ratio = FALSE;
 	gdouble desired_aspect = 1.777777778;
 	gdouble screenshot_aspect;
-	guint status_code;
+	gchar errbuf[CURL_ERROR_SIZE] = {'\0'};
 	guint screenshot_height;
 	guint screenshot_width;
 	guint ss_size_height_max = 900;
 	guint ss_size_height_min = 351;
 	guint ss_size_width_max = 1600;
 	guint ss_size_width_min = 624;
+	g_auto(GStrv) proxies = NULL;
 	g_autoptr(GdkPixbuf) pixbuf = NULL;
+	g_autoptr(GByteArray) buf = g_byte_array_new();
+	g_autoptr(GError) error_proxy = NULL;
 	g_autoptr(GInputStream) stream = NULL;
-	g_autoptr(SoupMessage) msg = NULL;
-	g_autoptr(SoupURI) base_uri = NULL;
 
 	/* make the requirements more strict */
 	if ((helper->flags & AS_APP_VALIDATE_FLAG_STRICT) > 0) {
@@ -453,37 +464,38 @@ ai_app_validate_image_check (AsImage *im, AsAppValidateHelper *helper)
 	/* GET file */
 	url = as_image_get_url (im);
 	g_debug ("checking %s", url);
-	base_uri = soup_uri_new (url);
-	if (!SOUP_URI_VALID_FOR_HTTP (base_uri)) {
-		ai_app_validate_add (helper,
-				     AS_PROBLEM_KIND_URL_NOT_FOUND,
-				     "<screenshot> url not valid [%s]", url);
-		return FALSE;
-	}
-	msg = soup_message_new_from_uri (SOUP_METHOD_GET, base_uri);
-	if (msg == NULL) {
-		g_warning ("Failed to setup message");
-		return FALSE;
+	(void)curl_easy_setopt(helper->curl, CURLOPT_URL, url);
+	(void)curl_easy_setopt(helper->curl, CURLOPT_FOLLOWLOCATION, 1);
+	(void)curl_easy_setopt(helper->curl, CURLOPT_ERRORBUFFER, errbuf);
+	(void)curl_easy_setopt(helper->curl,
+			       CURLOPT_WRITEFUNCTION,
+			       as_app_validate_download_write_callback_cb);
+
+	/* set proxy if required */
+	proxies = g_proxy_resolver_lookup(helper->proxy_resolver, url, NULL, &error_proxy);
+	if (proxies == NULL) {
+		g_warning("failed to lookup proxy for %s: %s", url, error_proxy->message);
+	} else if (g_strcmp0(proxies[0], "direct://") != 0) {
+		(void)curl_easy_setopt(helper->curl, CURLOPT_PROXY, proxies[0]);
 	}
 
-	/* send sync */
-	status_code = soup_session_send_message (helper->session, msg);
-	if (SOUP_STATUS_IS_TRANSPORT_ERROR(status_code)) {
+	(void)curl_easy_setopt(helper->curl, CURLOPT_WRITEDATA, buf);
+	res = curl_easy_perform(helper->curl);
+	if (res != CURLE_OK) {
+		if (errbuf[0] != '\0') {
+			ai_app_validate_add (helper,
+					     AS_PROBLEM_KIND_URL_NOT_FOUND,
+					     "<screenshot> url not valid [%s]: %s", url, errbuf);
+			return FALSE;
+		}
 		ai_app_validate_add (helper,
-			AS_PROBLEM_KIND_URL_NOT_FOUND,
-			"<screenshot> failed to connect: %s [%s]",
-			soup_status_get_phrase(status_code), url);
-		return FALSE;
-	} else if (status_code != SOUP_STATUS_OK) {
-		ai_app_validate_add (helper,
-			AS_PROBLEM_KIND_URL_NOT_FOUND,
-			"<screenshot> failed to download (HTTP %d: %s) [%s]",
-			status_code, soup_status_get_phrase(status_code), url);
+				     AS_PROBLEM_KIND_URL_NOT_FOUND,
+				     "<screenshot> url not valid [%s]: %s", url, curl_easy_strerror(res));
 		return FALSE;
 	}
 
 	/* check if it's a zero sized file */
-	if (msg->response_body->length == 0) {
+	if (buf->len == 0) {
 		ai_app_validate_add (helper,
 				     AS_PROBLEM_KIND_FILE_INVALID,
 				     "<screenshot> url is a zero length file [%s]",
@@ -492,8 +504,8 @@ ai_app_validate_image_check (AsImage *im, AsAppValidateHelper *helper)
 	}
 
 	/* create a buffer with the data */
-	stream = g_memory_input_stream_new_from_data (msg->response_body->data,
-						      (gssize) msg->response_body->length,
+	stream = g_memory_input_stream_new_from_data (buf->data,
+						      (gssize) buf->len,
 						      NULL);
 	if (stream == NULL) {
 		ai_app_validate_add (helper,
@@ -543,20 +555,20 @@ ai_app_validate_image_check (AsImage *im, AsAppValidateHelper *helper)
 	if (screenshot_height < ss_size_height_min) {
 		ai_app_validate_add (helper,
 				     AS_PROBLEM_KIND_ATTRIBUTE_INVALID,
-				     "<screenshot> height too small [%s] minimum is %upx",
-				     url, ss_size_height_min);
+				     "<screenshot> height (%u) too small [%s] minimum is %upx",
+				     screenshot_height, url, ss_size_height_min);
 	}
 	if (screenshot_width > ss_size_width_max) {
 		ai_app_validate_add (helper,
 				     AS_PROBLEM_KIND_ATTRIBUTE_INVALID,
-				     "<screenshot> width too large [%s] maximum is %upx",
-				     url, ss_size_width_max);
+				     "<screenshot> width (%u) too large [%s] maximum is %upx",
+				     screenshot_width, url, ss_size_width_max);
 	}
 	if (screenshot_height > ss_size_height_max) {
 		ai_app_validate_add (helper,
 				     AS_PROBLEM_KIND_ATTRIBUTE_INVALID,
-				     "<screenshot> height too large [%s] maximum is %upx",
-				     url, ss_size_height_max);
+				     "<screenshot> height (%u) too large [%s] maximum is %upx",
+				     screenshot_height, url, ss_size_height_max);
 	}
 
 	/* check padding */
@@ -651,7 +663,7 @@ as_app_validate_screenshot (AsScreenshot *ss, AsAppValidateHelper *helper)
 		im = g_ptr_array_index (images, i);
 		as_app_validate_image (im, helper);
 	}
-	tmp = as_screenshot_get_caption (ss, NULL);
+	tmp = as_screenshot_get_caption (ss, "C");
 	if (tmp != NULL) {
 		str_len = (guint) strlen (tmp);
 		if (str_len < length_caption_min) {
@@ -779,6 +791,7 @@ as_app_validate_screenshots (AsApp *app, AsAppValidateHelper *helper)
 	if (as_app_get_kind (app) == AS_APP_KIND_FIRMWARE ||
 	    as_app_get_kind (app) == AS_APP_KIND_DRIVER ||
 	    as_app_get_kind (app) == AS_APP_KIND_RUNTIME ||
+	    as_app_get_kind (app) == AS_APP_KIND_CONSOLE ||
 	    as_app_get_kind (app) == AS_APP_KIND_ADDON ||
 	    as_app_get_kind (app) == AS_APP_KIND_LOCALIZATION)
 		number_screenshots_min = 0;
@@ -993,20 +1006,9 @@ as_app_validate_releases (AsApp *app, AsAppValidateHelper *helper, GError **erro
 static gboolean
 as_app_validate_setup_networking (AsAppValidateHelper *helper, GError **error)
 {
-	helper->session = soup_session_new_with_options (SOUP_SESSION_USER_AGENT,
-							 "libappstream-glib",
-							 SOUP_SESSION_TIMEOUT,
-							 5000,
-							 NULL);
-	if (helper->session == NULL) {
-		g_set_error_literal (error,
-				     AS_APP_ERROR,
-				     AS_APP_ERROR_FAILED,
-				     "Failed to set up networking");
-		return FALSE;
-	}
-	soup_session_add_feature_by_type (helper->session,
-					  SOUP_TYPE_PROXY_RESOLVER_DEFAULT);
+	helper->curl = curl_easy_init();
+	(void)curl_easy_setopt(helper->curl, CURLOPT_USERAGENT, "libappstream-glib");
+	(void)curl_easy_setopt(helper->curl, CURLOPT_CONNECTTIMEOUT, 5L);
 	return TRUE;
 }
 
@@ -1133,8 +1135,8 @@ as_app_validate_helper_free (AsAppValidateHelper *helper)
 {
 	g_ptr_array_unref (helper->screenshot_urls);
 	g_free (helper->previous_para_was_short_str);
-	if (helper->session != NULL)
-		g_object_unref (helper->session);
+	if (helper->curl != NULL)
+		curl_easy_cleanup (helper->curl);
 	g_free (helper);
 }
 
@@ -1330,6 +1332,7 @@ as_app_validate (AsApp *app, guint32 flags, GError **error)
 	helper->probs = g_ptr_array_new_with_free_func ((GDestroyNotify) g_object_unref);
 	helper->screenshot_urls = g_ptr_array_new_with_free_func (g_free);
 	helper->flags = flags;
+	helper->proxy_resolver = g_proxy_resolver_get_default ();
 	if (!as_app_validate_setup_networking (helper, error))
 		return NULL;
 
@@ -1525,6 +1528,16 @@ as_app_validate (AsApp *app, guint32 flags, GError **error)
 					     AS_PROBLEM_KIND_TAG_INVALID,
 					     "<updatecontact> should be <update_contact>");
 		}
+		if ((problems & AS_APP_PROBLEM_DUPLICATE_PROJECT_LICENSE) > 0) {
+			ai_app_validate_add(helper,
+					    AS_PROBLEM_KIND_TAG_INVALID,
+					    "<project_license> was duplicated");
+		}
+		if ((problems & AS_APP_PROBLEM_DUPLICATE_METADATA_LICENSE) > 0) {
+			ai_app_validate_add(helper,
+					    AS_PROBLEM_KIND_TAG_INVALID,
+					    "<metadata_license> was duplicated");
+		}
 	}
 
 	/* check invalid values */
@@ -1765,7 +1778,7 @@ as_app_validate (AsApp *app, guint32 flags, GError **error)
 	}
 
 	/* developer_name */
-	name = as_app_get_developer_name (app, NULL);
+	name = as_app_get_developer_name (app, "C");
 	if (name != NULL) {
 		str_len = (guint) strlen (name);
 		if (str_len < length_name_min) {
