@@ -2,21 +2,7 @@
  *
  * Copyright (C) 2015 Richard Hughes <richard@hughsie.com>
  *
- * Licensed under the GNU Lesser General Public License Version 2.1
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
+ * SPDX-License-Identifier: LGPL-2.1+
  */
 
 /**
@@ -56,7 +42,7 @@ G_DEFINE_QUARK (as-inf-error-quark, as_inf_error)
  * Repairs .inf file data and opens it as a keyfile.
  *
  * Important: The group and keynames are all forced to lower case as INF files
- * are specified as case insensitve and GKeyFile *is* case sensitive.
+ * are specified as case insensitive and GKeyFile *is* case sensitive.
  * Any backslashes or spaces in the key name are also converted to '_'.
  *
  * Returns: %TRUE for success
@@ -72,7 +58,7 @@ as_inf_load_data (GKeyFile *keyfile,
 	g_set_error (error,
 		     AS_INF_ERROR,
 		     AS_INF_ERROR_FAILED,
-		     "Loading .inf data is no longer suported, see libginf");
+		     "Loading .inf data is no longer supported, see libginf");
 	return FALSE;
 }
 
@@ -98,7 +84,7 @@ as_inf_load_file (GKeyFile *keyfile,
 	g_set_error (error,
 		     AS_INF_ERROR,
 		     AS_INF_ERROR_FAILED,
-		     "Loading .inf files is no longer suported, see libginf");
+		     "Loading .inf files is no longer supported, see libginf");
 	return FALSE;
 }
 
@@ -120,6 +106,6 @@ as_inf_get_driver_version (GKeyFile *keyfile, guint64 *timestamp, GError **error
 	g_set_error (error,
 		     AS_INF_ERROR,
 		     AS_INF_ERROR_FAILED,
-		     "Loading .inf files is no longer suported, see libginf");
+		     "Loading .inf files is no longer supported, see libginf");
 	return NULL;
 }
